@@ -1,6 +1,6 @@
 package WWW::Google::Places::Params;
 
-$WWW::Google::Places::Params::VERSION = '0.13';
+$WWW::Google::Places::Params::VERSION = '0.14';
 $WWW::Google::Places::Params::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,11 @@ WWW::Google::Places::Params - Placeholder for parameters for WWW::Google::Places
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
+
+=head1 DESCRIPTION
+
+B<FOR INTERNAL USE ONLY>
 
 =cut
 
